@@ -209,6 +209,9 @@ LIMITEXCEEDED_PERIODEXCEEDMAXLIMIT = 'LimitExceeded.PeriodExceedMaxLimit'
 # 购买时长非法，时长最少1个月。
 LIMITEXCEEDED_PERIODLESSTHANMINLIMIT = 'LimitExceeded.PeriodLessThanMinLimit'
 
+# 请求的 redis 数量超过最大/最小购买数限制。
+LIMITEXCEEDED_REACHTHEAMOUNTLIMIT = 'LimitExceeded.ReachTheAmountLimit'
+
 # 复制组已锁定。
 LIMITEXCEEDED_REPLICATIONGROUPLOCKED = 'LimitExceeded.ReplicationGroupLocked'
 
@@ -284,6 +287,9 @@ RESOURCEUNAVAILABLE_NOENOUGHVIPINVPC = 'ResourceUnavailable.NoEnoughVipInVPC'
 # 请求的区域暂时不提供redis服务。
 RESOURCEUNAVAILABLE_NOREDISSERVICE = 'ResourceUnavailable.NoRedisService'
 
+# 请求的 zoneId 不提供 redis服务。
+RESOURCEUNAVAILABLE_NOSERVICEAVAILABLEFORTHISZONEID = 'ResourceUnavailable.NoServiceAvailableForThisZoneId'
+
 # 请求的区域暂时不提供请求类型的redis服务。
 RESOURCEUNAVAILABLE_NOTYPEIDREDISSERVICE = 'ResourceUnavailable.NoTypeIdRedisService'
 
